import { ReactNode } from "react";
import styled from "styled-components";
import BundlePrice from "../BundlePrice";
import BundleProduct from "../BundleProduct";
import Global from "../Helper";
import { BundleProps } from "./types";

function Bundle({
  width = 420,
  height = 215,
  backgroundColor = "blue",
  backgroundSrc,
}: BundleProps) {
  const StyledBundle = styled.div`
    display: flex;
    justify-content: center;
    align-items: flex-start;
    width: ${width}px;
    height: ${height}px;
    position: relative;
    border-radius: 20px;
    padding: 0.25em;
    background: linear-gradient(
      135deg,
      #fff35f 0%,
      #f58d07 50%,
      #d5670c 100%
    ); ;
  `;

  const StyledContainer = styled.div`
    height: calc(100% - 20px);
    width: 100%;
    border-radius: 15px;
    background: ${backgroundSrc
      ? `url("${backgroundSrc}")`
      : "linear-gradient(180deg, #1f3673 0%, #0b1031 100%)"};
    background-size: cover;
    display: flex;
    justify-content: center;
    align-items: center;
  `;

  const StyledProducts = styled.div`
    display: flex;
    flex-direction: row;
    gap: 1em;
  `;

  return (
    <Global>
      <StyledBundle>
        <StyledContainer>
          <StyledProducts>
            <BundleProduct
              color='#ffabff'
              img='https://animal-kingdom-media.s3.amazonaws.com/asset-2.png?a=a'
              amount={80}
            />
            <BundleProduct
              color='#ffe060'
              img='https://animal-kingdom-media.s3.amazonaws.com/asset-3.png?a=a'
              amount={50000}
            />
            <BundleProduct
              color='#60d9ff'
              img='https://animal-kingdom-media.s3.amazonaws.com/asset.png?a=a'
              amount={100}
            />
          </StyledProducts>
          <BundlePrice price={100} />
        </StyledContainer>
      </StyledBundle>
    </Global>
  );
}

export default Bundle;
